@@ -7,10 +7,10 @@ import unittest
 import uuid
 
 import dos_like
-from dos_like import dos
+from dos_like import _dos, dos
 
 
-class Tests(unittest.TestCase):
+class DosAPITests(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls) -> None:
@@ -105,7 +105,6 @@ class Tests(unittest.TestCase):
     def test_loadgif(self):
         gif_path = pathlib.Path(__file__).parent / 'data' / 'test.gif'
         gif = dos.loadgif(gif_path)
-        self.assertIsNotNone(gif)
         self.assertEqual('test.gif', gif.filename)
         self.assertEqual(3, gif.width)
         self.assertEqual(2, gif.height)
@@ -121,9 +120,9 @@ class Tests(unittest.TestCase):
             dos.RGB(0, 0, 0),
         ], gif.palette)
 
-    def test_loadgif_returns_none_for_nonexistent_path(self):
-        result = dos.loadgif(str(uuid.uuid4()))
-        self.assertIsNone(result)
+    def test_loadgif_raises_value_error_for_nonexistent_path(self):
+        with self.assertRaises(ValueError):
+            dos.loadgif(str(uuid.uuid4()))
 
     def test_blit(self):
         pixels = dos.new_buffer(b'\x01\x02\x03'
@@ -516,17 +515,16 @@ class Tests(unittest.TestCase):
                                  ('test.opb', dos.loadopb)]:
             path = pathlib.Path(__file__).parent / 'data' / filename
             music = loader(path)
-            self.assertIsNotNone(music, f'for {loader.__name__}("{path}")')
             self.assertEqual(filename, music.filename)
             dos.playmusic(music)
             self.assertTrue(dos.musicplaying(), f'for {path}')
             dos.stopmusic()
             self.assertFalse(dos.musicplaying(), f'for {path}')
 
-    def test_loadmid_nonexistent_music_paths_returns_none(self):
+    def test_load_nonexistent_music_paths_raises_value_error(self):
         for loader in dos.loadmid, dos.loadmus, dos.loadmod, dos.loadopb:
-            result = loader(str(uuid.uuid4()))
-            self.assertIsNone(result, f'for {loader.__name__}')
+            with self.assertRaises(ValueError, msg=f'for {loader.__name__}'):
+                loader(str(uuid.uuid4()))
 
     def test_musicvolume(self):
         dos.musicvolume(255)
@@ -536,22 +534,29 @@ class Tests(unittest.TestCase):
         with open(path, 'rb') as f:
             mus_data = f.read()
         music = dos.createmus(mus_data)
-        self.assertIsNotNone(music)
         self.assertIsNone(music.filename)
         dos.playmusic(music)
         self.assertTrue(dos.musicplaying())
         dos.stopmusic()
         self.assertFalse(dos.musicplaying())
 
+    def test_createmus_with_garbage_data_raises_value_error(self):
+        data = dos.new_buffer(b'\x00')
+        with self.assertRaises(ValueError):
+            dos.createmus(data)
+
     def test_load_and_play_wav(self):
         wav_path = pathlib.Path(__file__).parent / 'data' / 'test.wav'
         sound = dos.loadwav(wav_path)
-        self.assertIsNotNone(sound)
         dos.playsound(0, sound)
         self.assertTrue(dos.soundplaying(0))
         dos.stopsound(0)
         self.assertFalse(dos.soundplaying(0))
 
+    def test_load_nonexistent_wav_raises_value_error(self):
+        with self.assertRaises(ValueError):
+            dos.loadwav(str(uuid.uuid4()))
+
     def test_createsound(self):
         sample_rate = 8000
         period = 1 / 440
@@ -567,11 +572,10 @@ class Tests(unittest.TestCase):
                 value = -amplitude
             samples_ints.extend([value] * channels)
         samples_buffer = dos_like._dos.ffi.buffer(
-            dos_like._dos.ffi.new('short[]', samples_ints))
+            _dos.ffi.new('short[]', samples_ints))
 
         for samples in samples_ints, samples_buffer:
             sound = dos.createsound(channels, sample_rate, samples)
-            self.assertIsNotNone(sound, f'for samples {type(samples)}')
             dos.playsound(0, sound)
             self.assertTrue(dos.soundplaying(0),
                             f'for samples {type(samples)}')
@@ -579,6 +583,10 @@ class Tests(unittest.TestCase):
             self.assertFalse(dos.soundplaying(0),
                              f'for samples {type(samples)}')
 
+    def test_createsound_with_garbage_params_raises_value_error(self):
+        with self.assertRaises(ValueError):
+            dos.createsound(channels=1000, samplerate=999999, samples=[42])
+
     def test_mouse_coords(self):
         # Not much to test here
         dos.mousex()
@@ -590,16 +598,20 @@ class Tests(unittest.TestCase):
         with self.assertRaises(ValueError):
             dos.new_buffer()
 
-    def test_dos_setpal_with_mixed_args_fails(self):
+    def test_setpal_with_mixed_args_fails(self):
         with self.assertRaises(ValueError):
             dos.setpal(0, dos.RGB(1, 2, 3), 4, 5)
         with self.assertRaises(ValueError):
             dos.setpal(0, (1, 2, 3), 4, 5)
 
-    def test_dos_setpal_with_non_3_tuple_fails(self):
+    def test_setpal_with_non_3_tuple_fails(self):
         with self.assertRaises(ValueError):
             dos.setpal(0, (1, 2, 3, 4))
 
+    def test_setpal_with_1_int_fails(self):
+        with self.assertRaises(ValueError):
+            dos.setpal(0, 1)
+
     def test_setsoundmode(self):
         dos.setsoundmode(dos.soundmode_16bit_stereo_44100)
         # Not much else to test
@@ -607,3 +619,38 @@ class Tests(unittest.TestCase):
     def test_soundvolume(self):
         dos.soundvolume(0, 255, 255)
         # Not much else to test
+
+
+class GetFilenameTests(unittest.TestCase):
+
+    def test_none(self):
+        self.assertIsNone(dos.get_filename(None))
+
+    def test_bytes(self):
+        self.assertEqual('🎉', dos.get_filename('foo/🎉'.encode('utf-8')))
+
+    def test_str(self):
+        self.assertEqual('a string', dos.get_filename('bar/a string'))
+
+    def test_path(self):
+        self.assertEqual('a path',
+                         dos.get_filename(pathlib.Path('baaz/a path')))
+
+
+class BufferSizeTests(unittest.TestCase):
+
+    def test_cdata_buffer_size(self):
+        cdata = _dos.ffi.new('char[42]')
+        self.assertEqual(42, dos.buffer_size(cdata))
+
+    def test_buffer_buffer_size(self):
+        b = dos.new_buffer(size=27)
+        self.assertEqual(27, dos.buffer_size(b))
+
+    def test_list_buffer_size(self):
+        lst = [0] * 12
+        self.assertEqual(12, dos.buffer_size(lst))
+
+    def test_unsized_buffer_size_raises_value_error(self):
+        with self.assertRaises(ValueError):
+            dos.buffer_size(None)
